pub enum Event {
None,
CommandComplete,
TransferComplete,
Error {
normal: u16,
error: u16,
},
Other {
normal: u16,
error: u16,
},
}Expand description
Stable controller event extracted from SDHCI interrupt-status registers.
Variants
None
No status bit requiring runtime action is currently pending.
CommandComplete
A command response is ready to harvest.
TransferComplete
A data transfer has completed.
Error
One or more error bits are pending.
Other
Status bits are pending but do not map to a high-level event yet.